# Anyscale

This package contains the command line interface and the sdk for the Anyscale platform.

View Anyscale docs [here](https://docs.anyscale.com)
View CLI docs [here](https://docs.anyscale.com/reference/#cli)
View SDK docs [here](https://docs.anyscale.com/reference/#sdk)

After making any changes to the CLI, be sure to run `pip install -U -e .` from within the `frontend/cli` directory to update your environment with the latest modifications.
